@@ -1,4 +1,4 @@
-include Active;
+include Behavior::Active;
 
 class Agent with Active {
     # Should be required but will be moved to the Crudable area
@@ -8,4 +8,11 @@ class Agent with Active {
 
     include Artist;
     include Collector;
+
+    class Public {
+        method visit {
+            say "I visited";
+        }
+    }
+
 }
