@@ -5,7 +5,7 @@ package Art::World;
 # use Art::Agent;
 #has Art::Agent::Artist @.artists;
 
-our $VERSION = '0.15_05';
+our $VERSION = '0.16_01';
 
 use Zydeco;
 
@@ -26,7 +26,7 @@ Art::World - Agents interactions modeling  🎨
 =head1 OBJECTIVES
 
 
-Art::World is an attempt to model and simulate a system describing the interactions and influences between the various I<agents> of the art world.
+C<Art::World> is an attempt to model and simulate a system describing the interactions and influences between the various I<agents> of the art world.
 
 If a correct API is reached, we'll try to build a "game of art" frontend.
 
@@ -49,7 +49,7 @@ If a correct API is reached, we'll try to build a "game of art" frontend.
 
 =item 03 Idea comes from discourse (given about project)
 
-=item 04 Idea come when there is no time left
+=item 04 Idea comes when there is no time left
 
 =item 05 Ideas constitue the project
 
@@ -77,9 +77,9 @@ If a correct API is reached, we'll try to build a "game of art" frontend.
 
 =item 13 File is made of discourse
 
-=item 14 File archive ideas, that makes possible to forget them
+=item 14 File archives ideas, making possible to forget them
 
-=item 15 File generate a project
+=item 15 File generates a project
 
 =back
 
@@ -87,7 +87,7 @@ If a correct API is reached, we'll try to build a "game of art" frontend.
 
 =item 16 Discourse steers ideas
 
-=item 17 Discourse analyze process
+=item 17 Discourse analyzes process
 
 =item 18 Discourse talks about the file
 
@@ -99,9 +99,9 @@ If a correct API is reached, we'll try to build a "game of art" frontend.
 
 =over
 
-=item 21 From time to time, ideas appears
+=item 21 From time to time, ideas appear
 
-=item 22 Time needed to apply the process
+=item 22 Time is needed to apply the process
 
 =item 23 Time is suspended into file, process is off there
 
@@ -139,23 +139,21 @@ his own I<Suicide> in a book).
 
 2006 I initiated a FileMaker database of artworks to put the old style carton
 cards in computer form. I had no idea what I was doing at this time, being an
-art school student, at this time, programming was not massively teached at art
-school (unfortunately).
+art school student, at this time, programming was not massively taught as a fine art (unfortunately).
 
 In 2008 I benefited of an artist residency in an agricultural college with a
-creation grant of 10 000€. I urged to keep go on my I<Art World and Creative
-Processes schemas> projects initiated during art school. It didn't went very well
-because the then local state Plastic Art I<Inspector> didn't like what I was
-doing with her money and strongly advised to change orientation. In my idea, it
-was a perfect thing that the instutition itself would exhibit it's inherent
-processes and operations. In the end, there were an exhibition, but she didn't
+creation grant of 10 000€. I wanted to keep working on my I<Art World and Creative
+Processes schemas> projects initiated during art school. It didn't go very well
+because the Plastic Art I<State Inspector> didn't like what I was
+doing with her money and strongly advised to change orientation. In my opinion, it
+was a perfect thing that the instutition itself would exhibit it's own workings. In the end, there was an exhibition, but she didn't
 come to the opening.
 
 Anyway, I ended up interviewing many I<Agents> of the college, and went
 especially well with some natural sciences teacher. He recommended a manual were
 I found some schemas that I made some I<detournement>: I used the geology
 science as a metaphor of art world. I used geology terms and language to
-describe social interactions that are not described in the art sociology field.
+describe social interactions that were not described in the art sociology field.
 
 =begin html
 
@@ -166,14 +164,13 @@ describe social interactions that are not described in the art sociology field.
 
 =end html
 
-The residency ended up with L<the redaction of a rather precise documentation|https://files.balik.network/art/schema_v4_presentation.pdf> (maybe my first specification).  
+The residency ended up with L<the redaction of a rather precise documentation|https://files.balik.network/art/schema_v4_presentation.pdf> (maybe my first specification).
 
-Then I almost got hit by a fellow artist who was participating at a collective
-exhibition mostly for the money and not for the fun. I guess he got a bit provocated by my situationist theory.
+Then I almost got beaten by a fellow artist who was participating in a collective
+exhibition mostly for the money and not for the fun. I guess he felt a bit provoked by my situationist theory.
 
-In 2008, I finally decided to start a training to learn programming and being
-able to design a proper database and system for I<managing a virtual Art
-World>. I became a web developer, but I totally forgot the main aim.
+In 2008, I finally decided to start a training to learn programming and design a proper database and system for I<managing a virtual Art
+World>. I became a web developer, but I totally forgot the ulterior motive.
 
 Sometimes I thought about it:
 
@@ -181,7 +178,7 @@ Sometimes I thought about it:
 
 =item 2013 Perl try
 
-I bootstraped a Perl module with 5 abstract empty classes and then let it sleep on Github
+I bootstrapped a Perl module with 5 abstract empty classes and then let it sleep on Github
 
 =item 2017 Raku try
 
@@ -196,8 +193,13 @@ dreams|https://smonff.gitlab.io/art-school-story/>. I'll give it another try.
 
 =head1 AUTHOR
 
-Sébastien Feugère <sebastien@feugere.net>
-Seb. Hu-Rillettes <shr@balik.network>
+=over
+
+=item Sébastien Feugère <sebastien@feugere.net>
+
+=item Seb. Hu-Rillettes <shr@balik.network>
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
